### New Rules

Rule ID | Category | Severity | Notes
--------|----------|----------|------
ABIGEN001 | Abi.SourceGenerator | Error | ABI IDL file is missing from AdditionalFiles
ABIGEN002 | Abi.SourceGenerator | Error | Multiple ABI IDL files matched the configured path
ABIGEN003 | Abi.SourceGenerator | Error | ABI IDL file is empty or unreadable
ABIGEN004 | Abi.SourceGenerator | Error | ABI interop source generation failed
ABIGEN005 | Abi.SourceGenerator | Error | Managed metadata file is missing from AdditionalFiles
ABIGEN006 | Abi.SourceGenerator | Error | Multiple managed metadata files matched the configured path
ABIGEN007 | Abi.SourceGenerator | Error | Managed metadata file is empty or unreadable
ABIGEN008 | Abi.SourceGenerator | Warning | Managed handle type declared in metadata is missing in project source
ABIGEN009 | Abi.SourceGenerator | Error | Managed handle type must be a partial class
ABIGEN010 | Abi.SourceGenerator | Error | Managed handle type must inherit SafeHandle
ABIGEN011 | Abi.SourceGenerator | Error | Managed handle metadata access must match declared type accessibility
ABIGEN012 | Abi.SourceGenerator | Error | Managed metadata contains duplicate handle entries
ABIGEN013 | Abi.SourceGenerator | Error | Managed API metadata file is missing from AdditionalFiles
ABIGEN014 | Abi.SourceGenerator | Error | Multiple managed API metadata files matched the configured path
ABIGEN015 | Abi.SourceGenerator | Error | Managed API metadata file is empty or unreadable
